%Evaluates the legendre-polynomial of degree n
%The calculations are stored in persistent variables, so that the
%results can be reused if the function is called
%again with the same arguments

%Per Waagoe, 2010

function [res,calc]=P(n,x) 
persistent legp last_x;

%Reset persistent variables if x argument has changed
if ~isequal(x,last_x)
    legp={};
    last_x=x;
end

calc=false;
%Calculate only if it was not already calculatd for this degree
if length(legp)<=n || isempty(legp{n+1})
   legp{n+1}=calc_legp(n,x);
   calc=true;
end

res=legp{n+1};



function P=calc_legp(n,x)
Ptemp=legendre(n,x);
if isvector(x)
    P=Ptemp(1,:);
else
    if n==0
        P=Ptemp;
    else
        P=zeros(size(Ptemp,2),size(Ptemp,3));
        P(:,:)=Ptemp(1,:,:);
    end
end